#define XERR
#include "options.ih"

    // by options1.cc

void Options::precompileOpt()
{
    d_precompileOption = spchGch("--precompile", 'p');

    if (not d_precompileOption)
        return;

    disallowed("s");
}
