#define XERR "icmcomp"
#include "icmcomp.ih"

    // by handler/compile.cc, sourcescript/compile.cc

IcmComp::IcmComp(OptBase &optBase, Base::ExecType type, bool skipCompile)
:
    d_preCompOpts(dynamic_cast<PreCompOpts &>(optBase)),
    d_type(type),
    d_skipCompile(skipCompile)
{}
