#define XERR "stbase"
#include "stbase.ih"

    //by stbase1.cc, scriptopts/setbim.cc

void STBase::setTmp()
{
    d_tmp = tmpDir();

    if (src().empty())              // not a -t call
        return;

    d_tmp += src();                 // else add the src() name
    
    if (d_tmp.back() != '.')        // if not a final dot
        d_tmp.push_back('.');       // then add one.
}

