#include "generic.ih"

//#include <iostream>

Generic::Generic()
:
    d_verbose(false),
    d_noProcess(false),
    d_noVersionCheck(false),
    d_supportNoVersionCheck(false)
{
//    std::cout << __FILE__ ": versionCheck: " << d_versionCheck <<
//                " acceptNoVersionCheck: " << d_acceptNoVersionCheck << '\n';
}
