#define XERR
#include "options.ih"

void Options::setList(char const *optName)
{
    if (not plainSpchName(optName))         // the spch must be a plain name 
        return;

//    if (d_internal == d_required)           // check for equal extensions
//        emsg << "--internal and --required must specify "
//                "different extensions" << endl;
}
