inline bool PreCompOpts::preProcessed() const
{
    return d_preProcessed;
}

inline bool PreCompOpts::forced() const
{
    return d_action == FORCED;
}

inline void PreCompOpts::setScriptArg(std::string const &arg)
{
    d_scriptArg = arg;
}

inline std::string const &PreCompOpts::scriptArg() const
{
    return d_scriptArg;
}

inline PreCompOpts::StrVect const &PreCompOpts::eOptions() const
{
    return d_eOptions;
}

inline PreCompOpts::StrVect const &PreCompOpts::define() const
{
    return d_define;
}

inline std::string PreCompOpts::eOptsStr() const
{
    return catStr(d_eOptions);
}

inline std::string PreCompOpts::defineStr() const
{
    return catStr(d_define);
}

