#define XERR
#include "options.ih"

    // by options1.cc

void Options::unusedOpt()
{
                                        // files not inspected when
    string value;                       // constructed the SPCH
    if (d_unusedOption = d_arg.option(&value, 'u'); not d_unusedOption)
        return;

    error_code ec;
    if (value.find("f:") == 0)              // file containing regexes of
        readUnusedFile(value.substr(2));    // not-inspected files
    else
        s_unused = Pattern{ value };        // or a single pattern
}
