inline int CompileFork::ret() const
{
    return d_ret;
}
        
inline std::vector<std::string> const &CompileFork::lines() const
{
    return d_lines;
}
        

// inline std::string const &CompileFork::source() const
// {
//     return d_source;
// }
//         
// inline size_t CompileFork::size() const
// {
//     return d_lines.size();
// }
        
