#ifndef INCLUDED_TOKENS_
#define INCLUDED_TOKENS_

struct Tokens
{
    // Symbolic tokens:
    enum Tokens_
    {
        BOOL = 292,
        BREAK,
        CONTINUE,
        ELSE,
        EXIT,
        FOR,
        IDENTIFIER,
        IF,
        INT,
        LIST,
        NUMBER,
        RETURN,
        STRING,
        STRINGTYPE,
        VOID,
        WHILE,
        MATH_IS,
        OR,
        AND,
        EQUALITY,
        ORDER,
        SHIFT,
        MULTIPLY,
        INCDEC,
    };

};

#endif
