#define XERR
#include "options.ih"

    // by options1.cc

bool Options::allOpt()
{
                                // --all not specified? done here
    if (d_all = d_arg.option(&d_spch, 'a'); not d_all)
        return false;

    disallowed("lps");          // --all: options -l, -p, -s are not allowed
    setList("--all");
    setSpchGch();
    d_softLinkOption = true;

    return true;
}
