#define XERR
#include "options.ih"

    // by ./main.cc

Options::Options(unsigned argc, char **argv)
:
    Options(argv, argc)         // ensure construction -> destruction
{
    arguments();                // determine the action to perform
}
