    // by 
inline std::string const &OptBase::src() const
{
    return d_src;
}

inline size_t OptBase::tailIdx() const
{
    return optind;
}

inline void OptBase::setUsage()
{
    d_usage = true;
}

inline void OptBase::setVersion()
{
    d_version = true;
}

inline bool OptBase::usage() const
{
    return d_usage;
}

inline bool OptBase::version() const
{
    return d_version;
}

inline OptBase::StrVect const &OptBase::plainArgs() const
{
    return d_plainArgs;
}
