#define XERR
#include "options.ih"

// option is --precompile, --soft-link
// optChar is -p or -s

    // by precompileopt.cc softlinkopt.cc

bool Options::spchGch(char const *option, int optChar)
{
    if (not (d_arg.option(&d_spch, optChar) and plainSpchName(option)))
        return false;

    setSpchGch();       // compiler specification via Options::compilerSpec
    return true;
}   
