#define XERR "handler"
#include "handler.ih"

    // by process.cc

int Handler::sourceScript() const
{                                   // optBase() returns SourceOpts via
                                    //  Options::source()
    return SourceScript{ d_options.optBase() }.run();
}
