inline bool STBase::skipCompile() const
{
    return d_skipCompile;
}

inline void STBase::setSkipCompile(bool value)
{
    d_skipCompile = value;
}

    // by sourcescript/compile.cc
inline PreCompOpts STBase::compileOpts()
{
    return PreCompOpts{ d_compile, "d:hv", Base::COMPILE };
}

    // by scriptopts/tmpbim.cc scriptopts/imname.cc
inline std::string const &STBase::tmp() const
{
    return d_tmp;
}
